==> jc-1.4.0.tar.gz: javax/sql/RowSetEvent.h <==
// public class javax.sql.RowSetEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 3ea656b16d6b9d62 javax_sql_RowSetEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_sql_RowSetEvent_H_
#define _JC_javax_sql_RowSetEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_sql_RowSet$object;

// Typedefs
typedef struct _jc_javax_sql_RowSetEvent$sub_refs	_jc_javax_sql_RowSetEvent$sub_refs;
typedef struct _jc_javax_sql_RowSetEvent$sub_nonrefs	_jc_javax_sql_RowSetEvent$sub_nonrefs;
typedef struct _jc_javax_sql_RowSetEvent$refs	_jc_javax_sql_RowSetEvent$refs;
typedef struct _jc_javax_sql_RowSetEvent$nonrefs	_jc_javax_sql_RowSetEvent$nonrefs;
typedef struct _jc_javax_sql_RowSetEvent$object	_jc_javax_sql_RowSetEvent$object;

typedef const struct _jc_javax_sql_RowSetEvent$vmethods	_jc_javax_sql_RowSetEvent$vmethods;
typedef const struct _jc_javax_sql_RowSetEvent$vtable	_jc_javax_sql_RowSetEvent$vtable;
typedef const struct _jc_javax_sql_RowSetEvent$vtype	_jc_javax_sql_RowSetEvent$vtype;

// Constructors
extern void _jc_javax_sql_RowSetEvent$method$_init$f6c2be2a790a16a8(_jc_env *, struct _jc_javax_sql_RowSetEvent$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_javax_sql_RowSetEvent$vmethods {
};

// Vtable
struct _jc_javax_sql_RowSetEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_sql_RowSetEvent$vmethods	javax_sql_RowSetEvent;
};

// Vtype
struct _jc_javax_sql_RowSetEvent$vtype {
	_jc_type			type;
	_jc_javax_sql_RowSetEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_sql_RowSetEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_sql_RowSetEvent$refs {
    _jc_javax_sql_RowSetEvent$sub_refs	javax_sql_RowSetEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_sql_RowSetEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_sql_RowSetEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_sql_RowSetEvent$sub_nonrefs	javax_sql_RowSetEvent;
};

// Object instance structure
struct _jc_javax_sql_RowSetEvent$object {
	_jc_javax_sql_RowSetEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_sql_RowSetEvent$vtype	*vtype;
	_jc_javax_sql_RowSetEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_sql_RowSetEvent$vtype _jc_javax_sql_RowSetEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_sql_RowSetEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_sql_RowSetEvent$class_object;

#endif	/* _JC_javax_sql_RowSetEvent_H_ */

==> jc-1.4.6.tar.gz: javax/sql/RowSetEvent.h <==
// public class javax.sql.RowSetEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 3ea656b16d6b9d62 javax_sql_RowSetEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_sql_RowSetEvent_H_
#define _JC_javax_sql_RowSetEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_sql_RowSet$object;

// Typedefs
typedef struct _jc_javax_sql_RowSetEvent$sub_refs	_jc_javax_sql_RowSetEvent$sub_refs;
typedef struct _jc_javax_sql_RowSetEvent$sub_nonrefs	_jc_javax_sql_RowSetEvent$sub_nonrefs;
typedef struct _jc_javax_sql_RowSetEvent$refs	_jc_javax_sql_RowSetEvent$refs;
typedef struct _jc_javax_sql_RowSetEvent$nonrefs	_jc_javax_sql_RowSetEvent$nonrefs;
typedef struct _jc_javax_sql_RowSetEvent$object	_jc_javax_sql_RowSetEvent$object;

typedef const struct _jc_javax_sql_RowSetEvent$vmethods	_jc_javax_sql_RowSetEvent$vmethods;
typedef const struct _jc_javax_sql_RowSetEvent$vtable	_jc_javax_sql_RowSetEvent$vtable;
typedef const struct _jc_javax_sql_RowSetEvent$vtype	_jc_javax_sql_RowSetEvent$vtype;

// Constructors
extern void _jc_javax_sql_RowSetEvent$method$_init$f6c2be2a790a16a8(_jc_env *, struct _jc_javax_sql_RowSetEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_sql_RowSetEvent$vmethods {
};

// Vtable
struct _jc_javax_sql_RowSetEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_sql_RowSetEvent$vmethods	javax_sql_RowSetEvent;
};

// Vtype
struct _jc_javax_sql_RowSetEvent$vtype {
	_jc_type			type;
	_jc_javax_sql_RowSetEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_sql_RowSetEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_sql_RowSetEvent$refs {
    _jc_javax_sql_RowSetEvent$sub_refs	javax_sql_RowSetEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_sql_RowSetEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_sql_RowSetEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_sql_RowSetEvent$sub_nonrefs	javax_sql_RowSetEvent;
};

// Object instance structure
struct _jc_javax_sql_RowSetEvent$object {
	_jc_javax_sql_RowSetEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_sql_RowSetEvent$vtype	*vtype;
	_jc_javax_sql_RowSetEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_sql_RowSetEvent$vtype _jc_javax_sql_RowSetEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_sql_RowSetEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_sql_RowSetEvent$class_object;

#endif	/* _JC_javax_sql_RowSetEvent_H_ */
